==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/fe/SelectedMgrColumn.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/*
 * Copyright 2019 Tridium, Inc. All Rights Reserved.
 */

/**
 * API Status: **Private**
 * @module nmodule/saml/rc/fe/CircleOfTrustEditor
 */
define(['jquery', 'log!nmodule/saml/rc/fe/SelectedMgrColumn', 'Promise', 'bajaux/events', 'bajaux/Widget', 'nmodule/webEditors/rc/fe/baja/BooleanEditor', 'nmodule/webEditors/rc/fe/fe', 'nmodule/webEditors/rc/wb/mgr/model/columns/PropertyMgrColumn'], function ($, log, Promise, events, Widget, BooleanEditor, fe, PropertyMgrColumn) {
  'use strict';

  var logSevere = log.severe.bind(log);

  /**
  * Manager property column to render a checkboxes using the BooleanEditor in the manager table column.
  *
  * @class
  * @alias module:nmodule/saml/rc/fe/SelectedMgrColumn
  * @extends module:nmodule/webEditors/rc/wb/mgr/model/columns/PropertyMgrColumn
  */
  return /*#__PURE__*/function (_PropertyMgrColumn) {
    function SelectedMgrColumn() {
      _classCallCheck(this, SelectedMgrColumn);
      return _callSuper(this, SelectedMgrColumn, arguments);
    }
    _inherits(SelectedMgrColumn, _PropertyMgrColumn);
    return _createClass(SelectedMgrColumn, [{
      key: "buildCell",
      value:
      /**
       * Shows a checkbox display of the row's property value.
       *
       * @param {module:nmodule/webEditors/rc/wb/table/model/Row} row
       * @param {JQuery} dom
       * @returns {Promise} resolves when the cell has been built
       */
      function buildCell(row, dom) {
        return Promise.resolve(this.getValueFor(row)).then(function (value) {
          return fe.buildFor({
            dom: dom,
            type: BooleanEditor,
            value: value,
            properties: {
              trueText: " ",
              falseText: " "
            }
          }).then(function (propertyEditor) {
            // Register MODIFY_EVENT to update underlying component.
            return propertyEditor.jq().on(events.MODIFY_EVENT, function () {
              var subject = row.getSubject();
              propertyEditor.read().then(function (value) {
                return subject.set({
                  slot: 'selected',
                  value: value
                });
              })["catch"](logSevere);
            });
          });
        });
      }
    }, {
      key: "destroyCell",
      value:
      /**
       * Destroy the BooleanEditor that was created for this cell.
       *
       * @param {module:nmodule/webEditors/rc/wb/table/model/Row} row
       * @param {JQuery} dom
       * @returns {Promise}
       */
      function destroyCell(row, dom) {
        return Widget["in"](dom).destroy();
      }
    }]);
  }(PropertyMgrColumn);
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/fe/SelectedMgrColumn.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/*
 * Copyright 2019 Tridium, Inc. All Rights Reserved.
 */

/**
 * API Status: **Private**
 * @module nmodule/saml/rc/fe/CircleOfTrustEditor
 */
define(['jquery', 'log!nmodule/saml/rc/fe/SelectedMgrColumn', 'Promise', 'bajaux/events', 'bajaux/Widget', 'nmodule/webEditors/rc/fe/baja/BooleanEditor', 'nmodule/webEditors/rc/fe/fe', 'nmodule/webEditors/rc/wb/mgr/model/columns/PropertyMgrColumn'], function ($, log, Promise, events, Widget, BooleanEditor, fe, PropertyMgrColumn) {
  'use strict';

  var logSevere = log.severe.bind(log);

  /**
  * Manager property column to render a checkboxes using the BooleanEditor in the manager table column.
  *
  * @class
  * @alias module:nmodule/saml/rc/fe/SelectedMgrColumn
  * @extends module:nmodule/webEditors/rc/wb/mgr/model/columns/PropertyMgrColumn
  */
  return /*#__PURE__*/function (_PropertyMgrColumn) {
    function SelectedMgrColumn() {
      _classCallCheck(this, SelectedMgrColumn);
      return _callSuper(this, SelectedMgrColumn, arguments);
    }
    _inherits(SelectedMgrColumn, _PropertyMgrColumn);
    return _createClass(SelectedMgrColumn, [{
      key: "buildCell",
      value:
      /**
       * Shows a checkbox display of the row's property value.
       *
       * @param {module:nmodule/webEditors/rc/wb/table/model/Row} row
       * @param {JQuery} dom
       * @returns {Promise} resolves when the cell has been built
       */
      function buildCell(row, dom) {
        return Promise.resolve(this.getValueFor(row)).then(function (value) {
          return fe.buildFor({
            dom: dom,
            type: BooleanEditor,
            value: value,
            properties: {
              trueText: " ",
              falseText: " "
            }
          }).then(function (propertyEditor) {
            // Register MODIFY_EVENT to update underlying component.
            return propertyEditor.jq().on(events.MODIFY_EVENT, function () {
              var subject = row.getSubject();
              propertyEditor.read().then(function (value) {
                return subject.set({
                  slot: 'selected',
                  value: value
                });
              })["catch"](logSevere);
            });
          });
        });
      }

      /**
       * Destroy the BooleanEditor that was created for this cell.
       *
       * @param {module:nmodule/webEditors/rc/wb/table/model/Row} row
       * @param {JQuery} dom
       * @returns {Promise}
       */
    }, {
      key: "destroyCell",
      value: function destroyCell(row, dom) {
        return Widget["in"](dom).destroy();
      }
    }]);
  }(PropertyMgrColumn);
});
